--- debhelper-5.0.62/dh_installdocs 
+++ debhelper-5.0.62.new/dh_installdocs 
@@ -94,9 +94,50 @@
 between invocations of this command. Otherwise, it may cause multiple
 instances of the same text to be added to maintainer scripts.
 
+If the DEB_BUILD_OPTIONS environment variable contains "nodocs", only the
+copyright file will be installed - all other documentation, .docs file(s),
+README.Debian and TODO files are omitted.
+
 =cut
 
 init();
+
+sub handle_copyright($$)
+{
+	my ($tmp, $package) = @_;
+	# If the "directory" is a dangling symlink, then don't install
+	# the copyright file. This is useful for multibinary packages
+	# that share a doc directory.
+	if (-d "$tmp/usr/share/doc/$package") {
+		# Support debian/package.copyright, but if not present, fall
+		# back on debian/copyright for all packages, not just the
+		# main binary package.
+		my $copyright=pkgfile($package,'copyright');
+		if (! $copyright && -e "debian/copyright") {
+			$copyright="debian/copyright";
+		}
+		if ($copyright && ! excludefile($copyright)) {
+				doit("install","-g",0,"-o",0,"-m","644","-p",$copyright,
+					"$tmp/usr/share/doc/$package/copyright");
+		}
+	}
+}
+
+# This variable can be used to exclude all docs.
+if (defined $ENV{DEB_BUILD_OPTIONS} && $ENV{DEB_BUILD_OPTIONS} =~ /nodocs/) {
+	foreach my $package (@{$dh{DOPACKAGES}}) {
+		my $tmp=tmpdir($package);
+		next if is_udeb($package);
+		# If this is a symlink, leave it alone.
+		if ( ! -d "$tmp/usr/share/doc/$package" &&
+			 ! -l "$tmp/usr/share/doc/$package") {
+			doit("install","-g",0,"-o",0,"-d","$tmp/usr/share/doc/$package");
+		}
+		# ignore the .docs file(s), just put in copyright
+		&handle_copyright($tmp,$package);
+	}
+	exit;
+}
 
 foreach my $package (@{$dh{DOPACKAGES}}) {
 	next if is_udeb($package);
@@ -169,22 +210,7 @@
 		}
 	}
 
-	# If the "directory" is a dangling symlink, then don't install
-	# the copyright file. This is useful for multibinary packages 
-	# that share a doc directory.
-	if (-d "$tmp/usr/share/doc/$package") {
-		# Support debian/package.copyright, but if not present, fall
-		# back on debian/copyright for all packages, not just the 
-		# main binary package.
-		my $copyright=pkgfile($package,'copyright');
-		if (! $copyright && -e "debian/copyright") {
-			$copyright="debian/copyright";
-		}
-		if ($copyright && ! excludefile($copyright)) {
-				doit("install","-g",0,"-o",0,"-m","644","-p",$copyright,
-					"$tmp/usr/share/doc/$package/copyright");
-		}
-	}
+	&handle_copyright($tmp,$package);
 
 	# Handle doc-base files. There are two filename formats, the usual
 	# plus an extended format (debian/package.*).
